@@ -1,4 +1,4 @@
-# Copyright 1999-2000 by Roger S. Bivand
+# Copyright 1999-2003 by Roger S. Bivand
 #
 #
 # list.GRASS lists available GRASS data base files of the user-
@@ -6,13 +6,13 @@
 # 
 #
 list.GRASS <- function(type = "rast") {
-	if (system("which g.gisenv 2> /dev/null 1> /dev/null") != 0) {
-		help(pcbs)
-		stop("No GRASS environment detected - start GRASS before entering R")
+	if (length(Sys.getenv("GISBASE")) == 0) {
+	   stop("No GRASS environment detected - start GRASS before entering R")
 	}
 	res <- system(paste("g.list ", type, sep=""), intern=TRUE)
 	G.list <- character(0)
-	for(i in 3:(length(res)-1)) if (nchar(res[i]) > 0) G.list <- c(G.list, breakup(res[i]))
+	for(i in 3:(length(res)-1)) 
+	    if (nchar(res[i]) > 0) G.list <- c(G.list, breakup(res[i]))
 	invisible(G.list)
 }
 
